@@ -79,22 +79,22 @@ testIndNormLog = function(target, dataset, xIndex, csIndex, wei = NULL, univaria
     }
   }
   if (length(cs) == 0)  {
-    fit1 = glm(target ~ 1, family = gaussian(link = log), weights = wei, model = FALSE)
-    fit2 = glm(target ~ x, family = gaussian(link = log), weights = wei, model = FALSE) 
+    fit1 <- glm(target ~ 1, family = gaussian(link = log), weights = wei, model = FALSE)
+    fit2 <- glm(target ~ x, family = gaussian(link = log), weights = wei, model = FALSE) 
   } else {
-    fit1 = glm(target ~., data = as.data.frame( cs ), family = gaussian(link = log), weights = wei, model = FALSE)
-    fit2 = glm(target ~., data = as.data.frame( dataset[, c(csIndex, xIndex)] ), family = gaussian(link = log), weights = wei, model = FALSE)
+    fit1 <- glm(target ~., data = as.data.frame( cs ), family = gaussian(link = log), weights = wei, model = FALSE)
+    fit2 <- glm(target ~., data = as.data.frame( dataset[, c(csIndex, xIndex)] ), family = gaussian(link = log), weights = wei, model = FALSE)
   } 
   mod <- anova(fit1, fit2, test = "F")
   stat <- mod[2, 5]
   df1 <- mod[2, 3]
   df2 <- mod[2, 1]
-  pvalue = pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE ) 
+  pvalue <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE ) 
   
   #last error check
   if ( is.na(pvalue) || is.na(stat) )   {
-    pvalue = log(1);
-    stat = 0;
+    pvalue <- log(1);
+    stat <- 0;
   } else {
     #update hash objects
     if ( hash )  {
@@ -102,7 +102,6 @@ testIndNormLog = function(target, dataset, xIndex, csIndex, wei = NULL, univaria
       pvalue_hash[key] <- pvalue;        #.set(pvalue_hash , key , pvalue)
     }
   }
-  #testerrorcaseintrycatch(4);
   results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results)  
 }
\ No newline at end of file
